pub trait Merge {
type Item;
// Required method
fn insert(&mut self, item: Self::Item);
}Expand description
For collections that can be built from single elements.
Used by #[derive(FromSqlRow)] when a field is tagged with the attribute #[row(merge)].
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".